@@ -401,6 +401,7 @@ class CoreAgent:
 
     client_list = {}
     max_failed_retry = 5
+    max_failed_submissions_length = 100
 
     @classmethod
     def run(cls, host='localhost', port=6591):
@@ -523,7 +524,8 @@ class CoreAgent:
                     result = send_to_server(data_to_send,
                                             content_type=ReportType.Endpoint.value)
                     if not result:
-                        cls.failed_submissions.append(data_to_send)
+                        if len(cls.failed_submissions) < cls.max_failed_submissions_length:
+                            cls.failed_submissions.append(data_to_send)
                         log_error(f"Fail {datetime.now()} {window} {cls.endpoints_aggregate_data[key][window].get_dict()['num_operations']}")
                     cls.endpoints_aggregate_data[key].pop(window)
             except:
@@ -544,7 +546,8 @@ class CoreAgent:
                     result = send_to_server(data_to_send,
                                             content_type=ReportType.Task.value)
                     if not result:
-                        cls.failed_submissions.append(data_to_send)
+                        if len(cls.failed_submissions) < cls.max_failed_submissions_length:
+                            cls.failed_submissions.append(data_to_send)
                         log_error(f"Fail {datetime.now()} {window} {cls.tasks_aggregate_data[key][window].get_dict()['num_operations']}")
                     cls.tasks_aggregate_data[key].pop(window)
 
@@ -619,8 +622,18 @@ def get_parsed_operation(request_dict):
 
         result_type = ReportType.Endpoint.value
         commands = request_dict['BatchCommand']['commands']
-        request_start_time = datetime.strptime(commands.pop(0)['StartRequest']['timestamp'], '%Y-%m-%dT%H:%M:%S.%fZ')
-        request_finish_time = datetime.strptime(commands.pop(-1)['FinishRequest']['timestamp'], '%Y-%m-%dT%H:%M:%S.%fZ')
+        try:
+            request_start_time = datetime.strptime(commands.pop(0)['StartRequest']['timestamp'],
+                                                   '%Y-%m-%dT%H:%M:%S.%fZ')
+        except:
+            request_start_time = datetime.strptime(commands.pop(0)['StartRequest']['timestamp'],
+                                                   '%Y-%m-%dT%H:%M:%SZ')
+        try:
+            request_finish_time = datetime.strptime(commands.pop(-1)['FinishRequest']['timestamp'],
+                                                    '%Y-%m-%dT%H:%M:%S.%fZ')
+        except:
+            request_finish_time = datetime.strptime(commands.pop(-1)['FinishRequest']['timestamp'],
+                                                    '%Y-%m-%dT%H:%M:%SZ')
         request_elapsed_time = request_finish_time - request_start_time
         request_elapsed_time_us = timedelta_to_us(request_elapsed_time)
         request_method = None
@@ -657,7 +670,11 @@ def get_parsed_operation(request_dict):
                 if get_span_name(name) == 'View' or get_span_name(name) == 'Python':
                     operation_name = name.split('/')[1]
 
-                start_time = datetime.strptime(command['timestamp'], '%Y-%m-%dT%H:%M:%S.%fZ')
+                try:
+                    start_time = datetime.strptime(command['timestamp'], '%Y-%m-%dT%H:%M:%S.%fZ')
+                except:
+                    start_time = datetime.strptime(command['timestamp'], '%Y-%m-%dT%H:%M:%SZ')
+
                 elapsed_time = timedelta_to_us(stop_time - start_time)
 
                 if parent_id is None:
